@@ -37,5 +37,7 @@ CHARTS_NAMES = [
     'Dot',
     'Gauge',
     'DateY',
-    'Worldmap'
+    'Worldmap',
+    'SupranationalWorldmap',
+    'Histogram'
 ]
