@@ -22,12 +22,12 @@ Commmon graphing functions
 """
 
 from __future__ import division
-from pygal.interpolate import interpolation
+from pygal.interpolate import INTERPOLATIONS
 from pygal.graph.base import BaseGraph
 from pygal.view import View, LogView, XYLogView
 from pygal.util import (
-    is_major, truncate, reverse_text_len, get_texts_box, cut, rad)
-from math import isnan, pi, sqrt, ceil, cos
+    is_major, truncate, reverse_text_len, get_texts_box, cut, rad, decorate)
+from math import sqrt, ceil, cos
 from itertools import repeat, chain
 
 
@@ -42,6 +42,8 @@ class Graph(BaseGraph):
         self._axes()
         self._legend()
         self._title()
+        self._x_title()
+        self._y_title()
 
     def _axes(self):
         """Draw axes"""
@@ -83,6 +85,9 @@ class Graph(BaseGraph):
                       x=0, y=0,
                       width=self.view.width,
                       height=self.view.height)
+        self.nodes['title'] = self.svg.node(
+            self.nodes['graph'],
+            class_="titles")
         self.nodes['overlay'] = self.svg.node(
             self.nodes['graph'], class_="plot overlay",
             transform="translate(%d, %d)" % (
@@ -104,16 +109,20 @@ class Graph(BaseGraph):
         a = self.svg.node(self.nodes['tooltip'], 'a')
         self.svg.node(a, 'rect',
                       id="tooltip-box",
-                      rx=5, ry=5, width=0, height=0)
+                      rx=self.tooltip_border_radius,
+                      ry=self.tooltip_border_radius,
+                      width=0, height=0)
         text = self.svg.node(a, 'text', class_='text')
         self.svg.node(text, 'tspan', class_='label')
         self.svg.node(text, 'tspan', class_='value')
 
-    def _x_axis(self, draw_axes=True):
+    def _x_axis(self):
         """Make the x axis: labels and guides"""
         if not self._x_labels:
             return
-        axis = self.svg.node(self.nodes['plot'], class_="axis x")
+        axis = self.svg.node(self.nodes['plot'], class_="axis x%s" % (
+            ' always_show' if self.show_x_guides else ''
+        ))
         truncation = self.truncate_label
         if not truncation:
             if self.x_label_rotation or len(self._x_labels) <= 1:
@@ -123,11 +132,12 @@ class Graph(BaseGraph):
                 last_label_position = self.view.x(self._x_labels[-1][1])
                 available_space = (
                     last_label_position - first_label_position) / (
-                        len(self._x_labels) - 1)
+                    len(self._x_labels) - 1)
                 truncation = reverse_text_len(
                     available_space, self.label_font_size)
+                truncation = max(truncation, 1)
 
-        if 0 not in [label[1] for label in self._x_labels] and draw_axes:
+        if 0 not in [label[1] for label in self._x_labels]:
             self.svg.node(axis, 'path',
                           d='M%f %f v%f' % (0, 0, self.view.height),
                           class_='line')
@@ -135,7 +145,7 @@ class Graph(BaseGraph):
         if self.x_labels_major:
             x_labels_major = self.x_labels_major
         elif self.x_labels_major_every:
-            x_labels_major = [self._x_labels[i][0] for i in xrange(
+            x_labels_major = [self._x_labels[i][0] for i in range(
                 0, len(self._x_labels), self.x_labels_major_every)]
         elif self.x_labels_major_count:
             label_count = len(self._x_labels)
@@ -145,7 +155,7 @@ class Graph(BaseGraph):
             else:
                 x_labels_major = [self._x_labels[
                     int(i * (label_count - 1) / (major_count - 1))][0]
-                    for i in xrange(major_count)]
+                    for i in range(major_count)]
         else:
             x_labels_major = []
         for label, position in self._x_labels:
@@ -155,14 +165,13 @@ class Graph(BaseGraph):
             guides = self.svg.node(axis, class_='guides')
             x = self.view.x(position)
             y = self.view.height + 5
-            if draw_axes:
-                last_guide = (self._y_2nd_labels and label == lastlabel)
-                self.svg.node(
-                    guides, 'path',
-                    d='M%f %f v%f' % (x, 0, self.view.height),
-                    class_='%s%sline' % (
-                        'major ' if major else '',
-                        'guide ' if position != 0 and not last_guide else ''))
+            last_guide = (self._y_2nd_labels and label == lastlabel)
+            self.svg.node(
+                guides, 'path',
+                d='M%f %f v%f' % (x, 0, self.view.height),
+                class_='%s%sline' % (
+                    'major ' if major else '',
+                    'guide ' if position != 0 and not last_guide else ''))
             y += .5 * self.label_font_size + 5
             text = self.svg.node(
                 guides, 'text',
@@ -170,6 +179,10 @@ class Graph(BaseGraph):
                 y=y,
                 class_='major' if major else ''
             )
+
+            if isinstance(label, dict):
+                label = label['title']
+
             text.text = truncate(label, truncation)
             if text.text != label:
                 self.svg.node(guides, 'title').text = label
@@ -179,7 +192,9 @@ class Graph(BaseGraph):
 
         if self._x_2nd_labels:
             secondary_ax = self.svg.node(
-                self.nodes['plot'], class_="axis x x2")
+                self.nodes['plot'], class_="axis x x2%s" % (
+                    ' always_show' if self.show_x_guides else ''
+                ))
             for label, position in self._x_2nd_labels:
                 major = label in x_labels_major
                 if not (self.show_minor_x_labels or major):
@@ -199,14 +214,15 @@ class Graph(BaseGraph):
                     text.attrib['transform'] = "rotate(%d %f %f)" % (
                         -self.x_label_rotation, x, y)
 
-    def _y_axis(self, draw_axes=True):
+    def _y_axis(self):
         """Make the y axis: labels and guides"""
-        if not self._y_labels:
+        if not self._y_labels or not self.show_y_labels:
             return
 
         axis = self.svg.node(self.nodes['plot'], class_="axis y")
 
-        if 0 not in [label[1] for label in self._y_labels] and draw_axes:
+        if (0 not in [label[1] for label in self._y_labels] and
+                self.show_y_guides):
             self.svg.node(
                 axis, 'path',
                 d='M%f %f h%f' % (0, self.view.height, self.view.width),
@@ -221,7 +237,7 @@ class Graph(BaseGraph):
             y = self.view.y(position)
             if not y:
                 continue
-            if draw_axes:
+            if self.show_y_guides:
                 self.svg.node(
                     guides, 'path',
                     d='M%f %f h%f' % (0, y, self.view.width),
@@ -234,7 +250,11 @@ class Graph(BaseGraph):
                 y=y + .35 * self.label_font_size,
                 class_='major' if major else ''
             )
+
+            if isinstance(label, dict):
+                label = label['title']
             text.text = label
+
             if self.y_label_rotation:
                 text.attrib['transform'] = "rotate(%d %f %f)" % (
                     self.y_label_rotation, x, y)
@@ -265,9 +285,10 @@ class Graph(BaseGraph):
             return
         truncation = self.truncate_legend
         if self.legend_at_bottom:
-            x = self.margin.left + 10
+            x = self.margin.left + self.spacing
             y = (self.margin.top + self.view.height +
-                 self._x_labels_height + 10)
+                 self._x_title_height +
+                 self._x_labels_height + self.spacing)
             cols = ceil(sqrt(self._order)) or 1
 
             if not truncation:
@@ -276,8 +297,8 @@ class Graph(BaseGraph):
                 truncation = reverse_text_len(
                     available_space, self.legend_font_size)
         else:
-            x = 10
-            y = self.margin.top + 10
+            x = self.spacing
+            y = self.margin.top + self.spacing
             cols = 1
             if not truncation:
                 truncation = 15
@@ -305,13 +326,13 @@ class Graph(BaseGraph):
                 enumerate(zip(self._secondary_legends, repeat(True)))))
 
             # draw secondary axis on right
-            x = self.margin.left + self.view.width + 10
+            x = self.margin.left + self.view.width + self.spacing
             if self._y_2nd_labels:
                 h, w = get_texts_box(
                     cut(self._y_2nd_labels), self.label_font_size)
-                x += 10 + max(w * cos(rad(self.y_label_rotation)), h)
+                x += self.spacing + max(w * cos(rad(self.y_label_rotation)), h)
 
-            y = self.margin.top + 10
+            y = self.margin.top + self.spacing
 
             secondary_legends = self.svg.node(
                 self.nodes['graph'], class_='legends',
@@ -337,31 +358,60 @@ class Graph(BaseGraph):
                 height=self.legend_box_size,
                 class_="color-%d reactive" % (global_serie_number % 16)
             )
+
+            if isinstance(title, dict):
+                node = decorate(self.svg, legend, title)
+                title = title['title']
+            else:
+                node = legend
+
             truncated = truncate(title, truncation)
-            # Serious magical numbers here
             self.svg.node(
-                legend, 'text',
+                node, 'text',
                 x=col * x_step + self.legend_box_size + 5,
-                y=1.5 * row * h
-                + .5 * h
-                + .3 * self.legend_font_size
+                y=1.5 * row * h + .5 * h + .3 * self.legend_font_size
             ).text = truncated
+
             if truncated != title:
                 self.svg.node(legend, 'title').text = title
 
     def _title(self):
         """Make the title"""
         if self.title:
-            title_node = self.svg.node(
-                self.nodes['graph'],
-                class_="titles")
             for i, title_line in enumerate(self.title, 1):
                 self.svg.node(
-                    title_node, 'text', class_='title',
+                    self.nodes['title'], 'text', class_='title',
                     x=self.width / 2,
-                    y=i * (self.title_font_size + 10)
+                    y=i * (self.title_font_size + self.spacing)
                 ).text = title_line
 
+    def _x_title(self):
+        """Make the X-Axis title"""
+        y = (self.height - self.margin.bottom +
+             self._x_labels_height)
+        if self.x_title:
+            for i, title_line in enumerate(self.x_title, 1):
+                text = self.svg.node(
+                    self.nodes['title'], 'text', class_='title',
+                    x=self.margin.left + self.view.width / 2,
+                    y=y + i * (self.title_font_size + self.spacing)
+                )
+                text.text = title_line
+
+    def _y_title(self):
+        """Make the Y-Axis title"""
+        if self.y_title:
+            yc = self.margin.top + self.view.height / 2
+            for i, title_line in enumerate(self.y_title, 1):
+                text = self.svg.node(
+                    self.nodes['title'], 'text', class_='title',
+                    x=self._legend_at_left_width,
+                    y=i * (self.title_font_size + self.spacing) + yc
+                )
+                text.attrib['transform'] = "rotate(%d %f %f)" % (
+                    -90, self._legend_at_left_width, yc)
+                text.text = title_line
+
     def _serie(self, serie):
         """Make serie node"""
         return dict(
@@ -375,29 +425,20 @@ class Graph(BaseGraph):
                 self.nodes['text_overlay'],
                 class_='series serie-%d color-%d' % (serie, serie % 16)))
 
-    def _interpolate(
-            self, ys, xs,
-            polar=False, xy=False, xy_xmin=None, xy_rng=None):
+    def _interpolate(self, xs, ys):
         """Make the interpolation"""
-        interpolate = interpolation(
-            xs, ys, kind=self.interpolate)
-        p = self.interpolation_precision
-        xmin = min(xs)
-        xmax = max(xs)
-        interpolateds = []
-        for i in range(int(p + 1)):
-            x = i / p
-            if polar:
-                x = .5 * pi + 2 * pi * x
-            elif xy:
-                x = xy_xmin + xy_rng * x
-            interpolated = float(interpolate(x))
-            if not isnan(interpolated) and xmin <= x <= xmax:
-                coord = (x, interpolated)
-                if polar:
-                    coord = tuple(reversed(coord))
-                interpolateds.append(coord)
-        return interpolateds
+        x = []
+        y = []
+        for i in range(len(ys)):
+            if ys[i] is not None:
+                x.append(xs[i])
+                y.append(ys[i])
+
+        interpolate = INTERPOLATIONS[self.interpolate]
+
+        return list(interpolate(
+            x, y, self.interpolation_precision,
+            **self.interpolation_parameters))
 
     def _tooltip_data(self, node, value, x, y, classes=None):
         self.svg.node(node, 'desc', class_="value").text = value
@@ -433,14 +474,14 @@ class Graph(BaseGraph):
                 (x_pos[i], v)
                 for i, v in enumerate(serie.values)]
             if serie.points and self.interpolate:
-                serie.interpolated = self._interpolate(serie.values, x_pos)
+                serie.interpolated = self._interpolate(x_pos, serie.values)
             else:
                 serie.interpolated = []
 
     def _compute_secondary(self):
         # secondary y axis support
         if self.secondary_series and self._y_labels:
-            y_pos = zip(*self._y_labels)[1]
+            y_pos = list(zip(*self._y_labels))[1]
             if self.include_x_axis:
                 ymin = min(self._secondary_min, 0)
                 ymax = max(self._secondary_max, 0)
@@ -449,7 +490,7 @@ class Graph(BaseGraph):
                 ymax = self._secondary_max
             steps = len(y_pos)
             left_range = abs(y_pos[-1] - y_pos[0])
-            right_range = abs(ymax - ymin)
+            right_range = abs(ymax - ymin) or 1
             scale = right_range / (steps - 1)
             self._y_2nd_labels = [(self._format(ymin + i * scale), pos)
                                   for i, pos in enumerate(y_pos)]
