@@ -2,7 +2,7 @@
 # This file is part of pygal
 #
 # A python svg graph plotting library
-# Copyright © 2012 Kozea
+# Copyright © 2012-2013 Kozea
 #
 # This library is free software: you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -30,9 +30,10 @@ class HorizontalGraph(Graph):
         self.horizontal = True
         super(HorizontalGraph, self).__init__(*args, **kwargs)
 
-    def _compute(self):
-        super(HorizontalGraph, self)._compute()
+    def _post_compute(self):
         self._x_labels, self._y_labels = self._y_labels, self._x_labels
+        self._x_2nd_labels, self._y_2nd_labels = (
+            self._y_2nd_labels, self._x_2nd_labels)
 
     def _axes(self):
         self.view._force_vertical = True
