@@ -26,3 +26,11 @@ from pygal.graph.bar import Bar
 
 class HorizontalBar(HorizontalGraph, Bar):
     """Horizontal Bar graph"""
+
+    def _plot(self):
+        for index, serie in enumerate(self.series[::-1]):
+            num = len(self.series) - index - 1
+            self.bar(self._serie(num), serie, index)
+        for index, serie in enumerate(self.secondary_series[::-1]):
+            num = len(self.secondary_series) + len(self.series) - index - 1
+            self.bar(self._serie(num), serie, index + len(self.series), True)
