@@ -62,7 +62,7 @@ class Line(Graph):
         if rescale and self.secondary_series:
             points = [
                 (x, self._scale_diff + (y - self._scale_min_2nd) * self._scale)
-                for x, y in serie.points]
+                for x, y in serie.points if y is not None]
         else:
             points = serie.points
         view_values = list(map(self.view, points))
@@ -78,7 +78,6 @@ class Line(Graph):
                 if y > self.view.height / 2:
                     classes.append('top')
                 classes = ' '.join(classes)
-
                 dots = decorate(
                     self.svg,
                     self.svg.node(serie_node['overlay'], class_="dots"),
@@ -117,8 +116,8 @@ class Line(Graph):
 
         if self.include_x_axis:
         # Y Label
-            self._box.ymin = min(self._min, 0)
-            self._box.ymax = max(self._max, 0)
+            self._box.ymin = min(self._min or 0, 0)
+            self._box.ymax = max(self._max or 0, 0)
         else:
             self._box.ymin = self._min
             self._box.ymax = self._max
@@ -132,5 +131,6 @@ class Line(Graph):
     def _plot(self):
         for index, serie in enumerate(self.series):
             self.line(self._serie(index), serie)
+
         for index, serie in enumerate(self.secondary_series, len(self.series)):
             self.line(self._serie(index), serie, True)
