@@ -16,7 +16,9 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with pygal. If not, see <http://www.gnu.org/licenses/>.
-from pygal import Line, Dot, Pie, Radar, Config
+from pygal import (
+    Line, Dot, Pie, Radar, Config, Bar, Funnel, Worldmap,
+    SupranationalWorldmap, Histogram, Gauge)
 from pygal._compat import u
 from pygal.test.utils import texts
 from pygal.test import pytest_generate_tests, make_data
@@ -27,14 +29,26 @@ def test_config_behaviours():
     line1.show_legend = False
     line1.fill = True
     line1.pretty_print = True
+    line1.no_prefix = True
     line1.x_labels = ['a', 'b', 'c']
     line1.add('_', [1, 2, 3])
     l1 = line1.render()
 
+    q = line1.render_pyquery()
+    assert len(q(".axis.x")) == 1
+    assert len(q(".axis.y")) == 1
+    assert len(q(".plot .series path")) == 1
+    assert len(q(".legend")) == 0
+    assert len(q(".x.axis .guides")) == 3
+    assert len(q(".y.axis .guides")) == 21
+    assert len(q(".dots")) == 3
+    assert q(".axis.x text").map(texts) == ['a', 'b', 'c']
+
     line2 = Line(
         show_legend=False,
         fill=True,
         pretty_print=True,
+        no_prefix=True,
         x_labels=['a', 'b', 'c'])
     line2.add('_', [1, 2, 3])
     l2 = line2.render()
@@ -44,6 +58,7 @@ def test_config_behaviours():
         show_legend = False
         fill = True
         pretty_print = True
+        no_prefix = True
         x_labels = ['a', 'b', 'c']
 
     line3 = Line(LineConfig)
@@ -56,9 +71,22 @@ def test_config_behaviours():
     l4 = line4.render()
     assert l1 == l4
 
+    line_config = Config()
+    line_config.show_legend = False
+    line_config.fill = True
+    line_config.pretty_print = True
+    line_config.no_prefix = True
+    line_config.x_labels = ['a', 'b', 'c']
+
+    line5 = Line(line_config)
+    line5.add('_', [1, 2, 3])
+    l5 = line5.render()
+    assert l1 == l5
+
 
 def test_config_alterations_class():
     class LineConfig(Config):
+        no_prefix = True
         show_legend = False
         fill = True
         pretty_print = True
@@ -80,6 +108,7 @@ def test_config_alterations_class():
 
 def test_config_alterations_instance():
     class LineConfig(Config):
+        no_prefix = True
         show_legend = False
         fill = True
         pretty_print = True
@@ -102,6 +131,7 @@ def test_config_alterations_instance():
 
 def test_config_alterations_kwargs():
     class LineConfig(Config):
+        no_prefix = True
         show_legend = False
         fill = True
         pretty_print = True
@@ -170,7 +200,7 @@ def test_logarithmic_bad_interpolation():
     line = Line(logarithmic=True, interpolate='cubic')
     line.add('_', [.001, .00000001, 1])
     q = line.render_pyquery()
-    assert len(q(".y.axis .guides")) == 40
+    assert len(q(".y.axis .guides")) == 41
 
 
 def test_logarithmic_big_scale():
@@ -226,3 +256,26 @@ def test_no_data():
     line.no_data_text = u("þæ®þæ€€&ĳ¿’€")
     q = line.render_pyquery()
     assert q(".text-overlay text").text() == u("þæ®þæ€€&ĳ¿’€")
+
+
+def test_include_x_axis(Chart):
+    chart = Chart()
+    if Chart in (Pie, Radar, Funnel, Dot, Gauge, Worldmap,
+                 SupranationalWorldmap, Histogram):
+        return
+    if not chart.cls._dual:
+        data = 100, 200, 150
+    else:
+        data = (1, 100), (3, 200), (2, 150)
+    chart.add('_', data)
+    q = chart.render_pyquery()
+    # Ghost thing
+    yaxis = ".axis.%s .guides text" % (
+        'y' if not chart._last__inst.horizontal else 'x')
+    if not issubclass(chart.cls, Bar().cls):
+        assert '0.0' not in q(yaxis).map(texts)
+    else:
+        assert '0.0' in q(yaxis).map(texts)
+    chart.include_x_axis = True
+    q = chart.render_pyquery()
+    assert '0.0' in q(yaxis).map(texts)
