@@ -20,6 +20,7 @@ import os
 import pygal
 import uuid
 import sys
+from pygal import i18n
 from pygal.util import cut
 from pygal._compat import u
 from pygal.test import pytest_generate_tests, make_data
@@ -69,6 +70,8 @@ def test_metadata(Chart):
     v = range(7)
     if Chart == pygal.XY:
         v = list(map(lambda x: (x, x + 1), v))
+    elif Chart == pygal.Worldmap or Chart == pygal.SupranationalWorldmap:
+        v = list(map(lambda x: x, i18n.COUNTRIES))
 
     chart.add('Serie with metadata', [
         v[0],
@@ -91,7 +94,7 @@ def test_metadata(Chart):
     if Chart == pygal.Pie:
         # Slices with value 0 are not rendered
         assert len(v) - 1 == len(q('.tooltip-trigger').siblings('.value'))
-    elif Chart != pygal.Worldmap:
+    elif Chart != pygal.Worldmap and Chart != pygal.SupranationalWorldmap:
         # Tooltip are not working on worldmap
         assert len(v) == len(q('.tooltip-trigger').siblings('.value'))
 
@@ -115,12 +118,12 @@ def test_empty_lists_with_nones(Chart):
 
 
 def test_non_iterable_value(Chart):
-    chart = Chart()
+    chart = Chart(no_prefix=True)
     chart.add('A', 1)
     chart.add('B', 2)
     chart.x_labels = ('red', 'green', 'blue')
     chart1 = chart.render()
-    chart = Chart()
+    chart = Chart(no_prefix=True)
     chart.add('A', [1])
     chart.add('B', [2])
     chart.x_labels = ('red', 'green', 'blue')
@@ -129,13 +132,13 @@ def test_non_iterable_value(Chart):
 
 
 def test_iterable_types(Chart):
-    chart = Chart()
+    chart = Chart(no_prefix=True)
     chart.add('A', [1, 2])
     chart.add('B', [])
     chart.x_labels = ('red', 'green', 'blue')
     chart1 = chart.render()
 
-    chart = Chart()
+    chart = Chart(no_prefix=True)
     chart.add('A', (1, 2))
     chart.add('B', tuple())
     chart.x_labels = ('red', 'green', 'blue')
@@ -144,10 +147,10 @@ def test_iterable_types(Chart):
 
 
 def test_values_by_dict(Chart):
-    chart1 = Chart()
-    chart2 = Chart()
+    chart1 = Chart(no_prefix=True)
+    chart2 = Chart(no_prefix=True)
 
-    if Chart != pygal.Worldmap:
+    if not issubclass(Chart, pygal.Worldmap):
         chart1.add('A', {'red': 10, 'green': 12, 'blue': 14})
         chart1.add('B', {'green': 11, 'red': 7})
         chart1.add('C', {'blue': 7})
@@ -179,6 +182,12 @@ def test_no_data_with_no_values(Chart):
     assert q(".text-overlay text").text() == "No data"
 
 
+def test_no_data_with_no_values_with_include_x_axis(Chart):
+    chart = Chart(include_x_axis=True)
+    q = chart.render_pyquery()
+    assert q(".text-overlay text").text() == "No data"
+
+
 def test_no_data_with_empty_serie(Chart):
     chart = Chart()
     chart.add('Serie', [])
@@ -233,7 +242,7 @@ def test_unicode_labels_decode(Chart):
         'label': 'unicode <3'
     }])
     chart.x_labels = [u('&œ'), u('¿?'), u('††††††††'), 'unicode <3']
-    q = chart.render_pyquery()
+    chart.render_pyquery()
 
 
 def test_unicode_labels_python2(Chart):
@@ -255,7 +264,7 @@ def test_unicode_labels_python2(Chart):
         'label': eval("'unicode <3'")
     }])
     chart.x_labels = eval("[u'&œ', u'¿?', u'††††††††', 'unicode <3']")
-    q = chart.render_pyquery()
+    chart.render_pyquery()
 
 
 def test_unicode_labels_python3(Chart):
@@ -277,4 +286,55 @@ def test_unicode_labels_python3(Chart):
         'label': eval("b'unicode <3'")
     }])
     chart.x_labels = eval("['&œ', '¿?', '††††††††', 'unicode <3']")
+    chart.render_pyquery()
+
+
+def test_labels_with_links(Chart):
+    chart = Chart()
+    # link on chart and label
+    chart.add({
+        'title': 'Red', 'xlink': {'href': 'http://en.wikipedia.org/wiki/Red'}
+    }, [{
+        'value': 2,
+        'label': 'This is red',
+        'xlink': {'href': 'http://en.wikipedia.org/wiki/Red'}}])
+
+    # link on chart only
+    chart.add('Green', [{
+        'value': 4,
+        'label': 'This is green',
+        'xlink': {
+            'href': 'http://en.wikipedia.org/wiki/Green',
+            'target': '_top'}}])
+
+    # link on label only opens in new tab
+    chart.add({'title': 'Yellow', 'xlink': {
+        'href': 'http://en.wikipedia.org/wiki/Yellow',
+        'target': '_blank'}}, 7)
+
+    # link on chart only
+    chart.add('Blue', [{
+        'value': 5,
+        'xlink': {
+            'href': 'http://en.wikipedia.org/wiki/Blue',
+            'target': '_blank'}}])
+
+    # link on label and chart with diffrent behaviours
+    chart.add({
+        'title': 'Violet',
+        'xlink': 'http://en.wikipedia.org/wiki/Violet_(color)'
+    }, [{
+        'value': 3,
+        'label': 'This is violet',
+        'xlink': {
+            'href': 'http://en.wikipedia.org/wiki/Violet_(color)',
+            'target': '_self'}}])
+
     q = chart.render_pyquery()
+    links = q('a')
+
+    if issubclass(chart.cls, pygal.graph.worldmap.Worldmap):
+        # No country is found in this case so:
+        assert len(links) == 4  # 3 links and 1 tooltip
+    else:
+        assert len(links) == 8  # 7 links and 1 tooltip
